# This is a single package containing the beid-middleware, including the
# libraries as well as the firefox plugin used to register the libraries
# with firefox. This enables the use of Belgian eID, for signing and
# authentication for websites such as http://taxonweb.be . I put this all
# in one package, because this is always used together, and nothing else
# requires these files. This new version supersedes the old beid packages.

%define realname eid-mw

Name:		beid-middleware
Summary:	Application to read information from the Belgian e-ID card
Version:	5.1.8
Release:	%mkrel 1.1
# The original parts are under the "eID Toolkit Software License",
# which by my reading is BSD-like; it's basically the BSD in stronger
# legal language with some added gumph about liability etc. It also
# contains bits of OpenSC (which is LGPLv2+) and OpenSSL (which is
# BSD). - AdamW 2008/09
# Looking at the unofficial link ( http://code.google.com/p/eid-mw ) and
# at the license file inside the svn tree, it seems that it's now released
# as LGPLv3 - alien 2011
License:	LGPLv3
Group:		Security
URL:		https://eid.belgium.be/
Source0:	https://dist.eid.belgium.be/continuous/sources/%{realname}-%{version}-v%{version}mw.tar.gz

BuildRequires:	gtk3-devel
BuildRequires:	libproxy-devel
BuildRequires:  p11-kit-devel
BuildRequires:	pkgconfig(xerces-c)
BuildRequires:	pkgconfig(libpcsclite)
BuildRequires:	java
BuildRequires:	swig
BuildRequires:	subversion
BuildRequires:	zip
# need this for the c_rehash command
BuildRequires:	openssl-perl
Obsoletes:	beid < 5.0.0
Obsoletes:	%{_lib}beid2 < 5.0.0
Obsoletes:	%{_lib}beidcomm0 < 5.0.0
Obsoletes:	%{_lib}beidcommon0 < 5.0.0
Obsoletes:	%{_lib}beidgui1 < 5.0.0
Obsoletes:	%{_lib}beidlibopensc2 < 5.0.0
Obsoletes:	%{_lib}beidpcsclite2 < 5.0.0
Obsoletes:	%{_lib}beidpkcs11_2 < 5.0.0
# Suggesting the goverment supplied readers device drivers.
Recommends:	acr38u
Recommends:	ccid
Recommends:		pcsc-lite

%description
This application allows the user to read out any information from a
Belgian electronic ID card, by using libbeid and libbeidlibopensc to
read the data from the card and parse it. Both identity information
and information about the stored cryptographic keys can be read in a
user-friendly manner, and can easily be printed out or stored for
later review.

The application verifies the signature of the identity information,
checks whether it was signed by a government-issued key, and
optionally checks the certificate against the government's Certificate
Revocation List (CRL) and/or by using the Online Certificate Status
Protocol (OCSP) against the government's servers.

%package viewer
Requires:   %{name}
Summary:    Graphical application to read information from the Belgian e-ID card

%description viewer
This application allows the user to read out any information from a
Belgian electronic ID card, by using libbeid and libbeidlibopensc to
read the data from the card and parse it. Both identity information
and information about the stored cryptographic keys can be read in a
user-friendly manner, and can easily be printed out or stored for
later review.

The application verifies the signature of the identity information,
checks whether it was signed by a government-issued key, and
optionally checks the certificate against the government's Certificate
Revocation List (CRL) and/or by using the Online Certificate Status
Protocol (OCSP) against the government's servers.
This package provides the graphical viewer.

%package devel
Requires:   %{name}
Summary:    Graphical application to read information from the Belgian e-ID card

%description devel
Devel files for %{name}

%prep
%setup -q -n %{realname}-%{version}-v%{version}mw

%build
%configure --enable-p11v220 --enable-webextension
%make_build

%install
%make_install
# remove static libraries
rm -f %{buildroot}%{_libdir}/*.{la,a}
# remove development libraries
rm -f %{buildroot}%{_libdir}/libbeid*.so
# remove contents of the xpi
#rm -rf %{buildroot}%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/belgiumeid@eid.belgium.be
# install the xpi itself
install -D -m 755 plugins_tools/xpi/signed-build/belgium_eid-1.0.32.xpi %{buildroot}%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/belgiumeid@eid.belgium.be.xpi
install -D -m 755 plugins_tools/xpi/signed-build/eid_belgie-1.0.23.xpi %{buildroot}%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/eid_belgie@eid.belgium.be.xpi

%find_lang about-eid-mw
%find_lang dialogs-beid

# remove extra stuff for now, we'll do proper extra packages later on
# first, eid-viewer stuff

%files -f about-eid-mw.lang -f dialogs-beid.lang
%defattr(-, root, root, 0755)
%{_libdir}/libbeid*
%{_libexecdir}/beid-*
%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/belgiumeid@eid.belgium.be.xpi
%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/eid_belgie@eid.belgium.be.xpi
%{_datadir}/eid-mw
%{_bindir}/about-eid-mw

%{_sysconfdir}/xdg/autostart/beid-update-nssdb.desktop
%{_bindir}/beid-update-nssdb

/usr/lib/mozilla/pkcs11-modules/beidpkcs11.json
/usr/lib/mozilla/pkcs11-modules/beidpkcs11_alt.json
/usr/lib/mozilla/managed-storage/belgiumeid@eid.belgium.be.json
%{_libdir}/pkgconfig/libbeidpkcs11.pc
%{_datadir}/p11-kit/modules/beid.module

%files viewer
%{_datadir}/applications/eid-viewer.desktop
%{_bindir}/eid-viewer
%{_libdir}/libeidviewer.so.*
%{_datadir}/icons/hicolor/*/apps/eid-viewer.png
%{_datadir}/locale/*/LC_MESSAGES/eid-viewer.mo
%{_datadir}/glib-2.0/schemas/eid-viewer.gschema.xml
%{_datadir}/metainfo/be.belgium.eid.eidmw.metainfo.xml
%{_datadir}/metainfo/eid-viewer.appdata.xml

%files devel
%{_libdir}/libeidviewer.so
%{_libdir}/pkcs11/beidpkcs11.so
%{_includedir}/beid
%{_includedir}/eid-viewer
%{_includedir}/eid-util


%changelog
* Sat Dec 03 2022 papoteur <papoteur> 5.1.8-1.1.mga8
+ Revision: 1915982
- new 5.1.8 (mga#27077)

* Tue Oct 27 2020 tv <tv> 4.4.8-3.mga8
+ Revision: 1639778
- fix filelist

* Fri Feb 14 2020 umeabot <umeabot> 4.4.8-2.mga8
+ Revision: 1520677
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Tue Dec 04 2018 alien <alien> 4.4.8-1.mga7
+ Revision: 1338358
- Update to 4.4.8
- build xpi using webextension
- add dialog translations

* Fri Sep 21 2018 umeabot <umeabot> 4.1.2-6.mga7
+ Revision: 1295403
- Mageia 7 Mass Rebuild

* Sat Feb 13 2016 umeabot <umeabot> 4.1.2-5.mga6
+ Revision: 959585
- Mageia 6 Mass Rebuild

* Sun Jul 05 2015 alien <alien> 4.1.2-4.mga6
+ Revision: 851708
- Update to version 4.1.2
- Add an 'about' application

* Wed Oct 15 2014 umeabot <umeabot> 4.0.6-4.mga5
+ Revision: 743356
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.0.6-3.mga5
+ Revision: 678139
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sun Sep 07 2014 alien <alien> 4.0.6-2.mga5
+ Revision: 673241
+ rebuild (emptylog)

* Sun Aug 31 2014 alien <alien> 4.0.6-1.mga5
+ Revision: 669810
- Update to new version
- adjust library-fix patch

* Mon Oct 21 2013 umeabot <umeabot> 4.0.4-2.mga4
+ Revision: 539295
- Mageia 4 Mass Rebuild

* Sat Oct 05 2013 alien <alien> 4.0.4-1.mga4
+ Revision: 491810
- Fix building with newer autotools
- package into a .xpi
- Update to new version
- also package the helper tools
- Suggest also ccid
- Switch to upstream release

* Fri Jan 11 2013 umeabot <umeabot> 4.0.0.r929-7.mga3
+ Revision: 346891
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Oct 03 2012 malo <malo> 4.0.0.r929-6.mga3
+ Revision: 302582
- update RPM group

* Sun Aug 19 2012 sander85 <sander85> 4.0.0.r929-5.mga3
+ Revision: 282154
- Fix build with gcc 4.7
+ luigiwalser <luigiwalser>
- rebuild for libffi

* Mon Sep 19 2011 fwang <fwang> 4.0.0.r929-4.mga2
+ Revision: 145282
- rebuild for new libpng
+ alien <alien>
- Fix patch to -P1
- Fix xpi for FF5

* Thu Jun 23 2011 alien <alien> 4.0.0.r929-2.mga2
+ Revision: 112561
- Fix missing obsoletes

* Thu Jun 16 2011 alien <alien> 4.0.0.r929-1.mga2
+ Revision: 108311
- Remove old beidgui references
- Remove development libraries
- Add packaging explanation comment regarding not splitting up the package
- Fix a library linking issue
- Remove static libraries
- imported package beid-middleware

